referrer_of

Function referrer_of 

pub fn referrer_of<'k>(scan: &NarRefScan<'_>, key: &'k str) -> Option<&'k str>
Recover the referring store-path hash from a scanned edge key.

Returns None for a key that is not under scan — a listing that returns a neighbouring key must not be silently read as a referrer.