pub struct StorageIndex { /* private fields */ }Expand description
Ephemeral metadata index backed by redb.
Implementations
Sourceimpl StorageIndex
impl StorageIndex
Sourcepub fn open(path: &Path) -> Result<StorageIndex, StoreError>
pub fn open(path: &Path) -> Result<StorageIndex, StoreError>
Open or create the index at the given path.
Errors
Returns StoreError::Io if the database cannot be opened or the
schema tables cannot be created.
Sourcepub fn index_narinfo(&self, hash: &str, nar_size: u64) -> Result<(), StoreError>
pub fn index_narinfo(&self, hash: &str, nar_size: u64) -> Result<(), StoreError>
Sourcepub fn index_store_path(
&self,
store_path: &str,
hash: &str,
) -> Result<(), StoreError>
pub fn index_store_path( &self, store_path: &str, hash: &str, ) -> Result<(), StoreError>
Sourcepub fn has_narinfo(&self, hash: &str) -> Result<bool, StoreError>
pub fn has_narinfo(&self, hash: &str) -> Result<bool, StoreError>
Sourcepub fn list_hashes(&self) -> Result<Vec<String>, StoreError>
pub fn list_hashes(&self) -> Result<Vec<String>, StoreError>
Sourcepub fn count(&self) -> Result<u64, StoreError>
pub fn count(&self) -> Result<u64, StoreError>