Ed25519 signing for narinfo metadata.
Each cache has a key pair identified by a key name. The CacheSigner
signs the narinfo fingerprint (the canonical string that Nix signs)
and produces a keyname:base64sig string that goes into the Sig: field.
Structs
- Cache
Signer - Signs narinfo metadata with an ed25519 key pair.
Functions
- verify_
narinfo_ signature - Verify that a narinfo signature is valid against a public key string.